
#include "config.h"

#if STATIC_SCRIPTS

#include "static_scripts.h"

/* testscript */
static const uint8_t testscript_flash1[] PROGMEM = {
    MACRO_WAIT(_BV(CHANNEL_RED)),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0xff),
    MACRO_WAIT(_BV(CHANNEL_RED)),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0),
    MACRO_JUMP(-4),
    MACRO_STOP()
    };

/* tun colors off */
static const uint8_t turn_off_red[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_RED, 0),
    MACRO_STOP()
    };

static const uint8_t turn_off_green[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 0),
    MACRO_STOP()
    };

static const uint8_t turn_off_blue[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0),
    MACRO_STOP()
    };

/* turn colors on */
static const uint8_t turn_on_red[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_RED, 255),
    MACRO_STOP()
    };

static const uint8_t turn_on_green[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 255),
    MACRO_STOP()
    };

static const uint8_t turn_on_blue[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 255),
    MACRO_STOP()
    };

/* fade red slowly */
static const uint8_t fade_red[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_RED, 255),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 0, 0x20),
    MACRO_WAIT(_BV(CHANNEL_RED)),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 255, 0x20),
    MACRO_WAIT(_BV(CHANNEL_RED)),
    MACRO_JUMP(-4),
    };

/* fade green slowly but a little bit faster than red */
static const uint8_t fade_green[] PROGMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 255, 0x22),
    MACRO_WAIT(_BV(CHANNEL_GREEN)),
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 0, 0x22),
    MACRO_WAIT(_BV(CHANNEL_GREEN)),
    MACRO_JUMP(-4),
    };

/* fade blue slowly but a little bit faster than green */
static const uint8_t fade_blue[] PROGMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_BLUE, 255, 0x24),
    MACRO_WAIT(_BV(CHANNEL_BLUE)),
    MACRO_FADE_CHANNEL(CHANNEL_BLUE, 0, 0x24),
    MACRO_WAIT(_BV(CHANNEL_BLUE)),
    MACRO_JUMP(-4),
    };

static const uint8_t testscript_flash2[] PROGMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_RED, 255, 0x50),
    MACRO_WAIT(_BV(CHANNEL_RED)),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 100, 0x50),
    MACRO_WAIT(_BV(CHANNEL_RED)),
    MACRO_JUMP(-4),
    };


static const uint8_t testscript_eeprom[] EEMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 255, 0xf00),
    MACRO_WAIT(_BV(CHANNEL_GREEN)),
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 0, 0x100),
    MACRO_WAIT(_BV(CHANNEL_GREEN)),
    MACRO_JUMP(-4)
    };


static const uint8_t colorchange_red[] PROGMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_RED, 255, 0x200),

    MACRO_WAIT(_BV(CHANNEL_RED)|_BV(CHANNEL_GREEN)|_BV(CHANNEL_BLUE)),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 0, 0x040),
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 255, 0x040),
    MACRO_WAIT(_BV(CHANNEL_RED)|_BV(CHANNEL_GREEN)|_BV(CHANNEL_BLUE)),
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 0, 0x040),
    MACRO_FADE_CHANNEL(CHANNEL_BLUE, 255, 0x040),
    MACRO_WAIT(_BV(CHANNEL_RED)|_BV(CHANNEL_GREEN)|_BV(CHANNEL_BLUE)),
    MACRO_FADE_CHANNEL(CHANNEL_BLUE, 0, 0x040),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 255, 0x040),
    MACRO_JUMP(-9)
    };

static const uint8_t colorchange_red_blue[] PROGMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_RED, 255, 0x200),

    MACRO_WAIT(_BV(CHANNEL_RED)|_BV(CHANNEL_BLUE)),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 0, 0x040),
    MACRO_FADE_CHANNEL(CHANNEL_BLUE, 255, 0x040),
    MACRO_WAIT(_BV(CHANNEL_RED)|_BV(CHANNEL_BLUE)),
    MACRO_FADE_CHANNEL(CHANNEL_BLUE, 0, 0x040),
    MACRO_FADE_CHANNEL(CHANNEL_RED, 255, 0x040),
    MACRO_JUMP(-6)
    };


static const uint8_t green_flash[] PROGMEM = {
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 255, 0xf00),
    MACRO_WAIT(_BV(CHANNEL_GREEN)),
    MACRO_FADE_CHANNEL(CHANNEL_GREEN, 0, 0x100),
    MACRO_WAIT(_BV(CHANNEL_GREEN)),
    MACRO_STOP()
    };

static const uint8_t green_blink[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 150),
    MACRO_SLEEP(125),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 0),
    MACRO_SLEEP(125),
    MACRO_JUMP(-4)
    };

static const uint8_t blinken[] PROGMEM = {
    MACRO_SET_CHANNEL(CHANNEL_RED, 255),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 0),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0),
    MACRO_SLEEP(125),
    MACRO_SET_CHANNEL(CHANNEL_RED, 0),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 255),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0),
    MACRO_SLEEP(125),
    MACRO_SET_CHANNEL(CHANNEL_RED, 0),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 0),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 255),
    MACRO_SLEEP(125),
    MACRO_SET_CHANNEL(CHANNEL_RED, 128),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 0),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0),
    MACRO_SLEEP(125),
    MACRO_SET_CHANNEL(CHANNEL_RED, 0),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 128),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 0),
    MACRO_SLEEP(125),
    MACRO_SET_CHANNEL(CHANNEL_RED, 0),
    MACRO_SET_CHANNEL(CHANNEL_GREEN, 0),
    MACRO_SET_CHANNEL(CHANNEL_BLUE, 128),
    MACRO_SLEEP(125),
    MACRO_JUMP(-24)
    };

#endif
